fedex.services.package_movement

Package fedex :: Package services :: Module package_movement |
[hide private]
[frames] | no frames]

# Module package_movement

source code

# Package Movement Information Service

This package contains classes to check service availability, route, and postal codes. Defined by the PackageMovementInformationService WSDL file.

Classes | [hide private]
| FedexPostalCodeNotFound Exception: Sent when the postalcode is missing.
| FedexInvalidPostalCodeFormat Exception: Sent when the postal code is invalid
| PostalCodeInquiryRequest The postal code inquiry enables customers to validate postal codes and service commitments.

Variables | [hide private]
| __package__ = ``'``fedex.services``'``